/*
Copyright (C) 1999/2000 Hendrik Lipka.
All rights reserved.

This program is free software; you can redistribute it and/or modify it under the terms 
of the GNU General Public License as published by the Free Software Foundation; 
either version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY 
WARRANTY; without even the implied warranty of MERCHANTABILITY or 
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License 
for more details. 

You should have received a copy of the GNU General Public License along with this 
program; if not, write to the Free Software Foundation, Inc., 675 Mass Ave, 
Cambridge, MA 02139, USA or see http://www.gnu.org

If you encounter problems or have a suggestion, please mail to:
ldse@hendriklipka.de
*/

package de.hendriklipka.ldse.server.broker;

import java.io.*;
import java.net.*;
import java.util.Vector;

import com.objectspace.jgl.Container;
import com.objectspace.jgl.SList;

import de.hendriklipka.ldse.common.ResultDescriptor;
import de.hendriklipka.ldse.common.Log;
import de.hendriklipka.ldse.common.ResultParser;
import de.hendriklipka.ldse.common.ResultListener;
import de.hendriklipka.ldse.server.broker.BrokerQuery;
import de.hendriklipka.ldse.server.dataserver.DBConnection;
import de.hendriklipka.ldse.server.query.QueryLimits;

/**
  Abfrage eines einzelnen Subservers
*/
public class BrokerConnection
{
  protected DBConnection _con;
  protected String _server=null;
  protected int _port=-1;
  protected boolean _isLocal=true;
  
  protected Container _result=null;
  protected BrokerQuery _query=null;

  public BrokerConnection(DBConnection con, BrokerQuery query)
  {
    _con=con;
    _query=query;
    _isLocal=true;
  }
  
  public BrokerConnection(String server, int port, BrokerQuery query)
  {
    _server=server;
    _port=port;
    _query=query;
    _isLocal=false;
  }
  
  public void doQuery()
  {
    if (_isLocal)
    {
      // init und PreProcess wurden bereits ausgefuehrt...
      _query.getQueryProcessor().doQuery(_con);
      _query.getQueryProcessor().postprocessQuery(_con);
      _result=_query.getQueryProcessor().getResult();
    }
    else
    {
      // Query verschicken und Ergebnisse einlesen
      // erstmal den Querystring zusammenbauen:
      String query="<?xml version=\"1.0\"?>\n";
      query+="<query>\n";
      // bei den Limits zaehlt nur der Level, maxCount wird erst
      // beim Zusammenbauen benutzt
      double minLevel=0;
      if (null!=_query.getLimits())
      {
        minLevel=_query.getLimits()._minLevel;
      }
      query+="<limit minlevel=\""+minLevel+"\"/>\n";
      query+=_query.getQuery();
      query+="\n</query>\n";

      // Abfrage per hand stellen
      try
      {
        // Verbindung oeffnen
        Reader r;
        Writer w;
        Socket s=new Socket(InetAddress.getByName(_server),_port);
        s.setSoTimeout(5*60*1000); // 5 Minuten Timeout
        r=new InputStreamReader(s.getInputStream());
        w=new OutputStreamWriter(s.getOutputStream());
        // Query-String schreiben
        w.write(query);
        w.flush();
        // Parser erzeugen
        ResultParser rp=new ResultParser();
        Listener rl=new Listener();
        rp.init(r);
        rp.addResultListener(rl);
        // Result einlesen
        rp.readResult();
        r.close();
        w.close();
        s.close();
      }
      catch (Throwable ex)
      {
        ex.printStackTrace();
      }
    }
  }
  
  public Container getResult()
  {
    return _result;
  }
  
  class Listener implements ResultListener
  {
    public void startResult()
    {
      if (null==_result)
        _result=new SList();
    }
    
    public void addResult(de.hendriklipka.ldse.common.ResultDescriptor rd)
    {
      ResultDescriptor _rd=new ResultDescriptor();
      _rd.setRelevance(rd.getRelevance());
      _rd.setTitle(rd.getTitle());
      _rd.setExcerpt(rd.getExcerpt());
      _rd.setLastChange(rd.getLastChange());
      _rd.setSize(rd.getSize());
      _rd.setType(rd.getType());
      _rd.setURL(rd.getURL());
      _result.add(_rd);
      BrokerServer._resultDocs++;
    }
    
    public void setResultNum(int num)
    {
    }
    
    public void endResult()
    {
    }
  }
}